<?php

function dnd_character_admin_page() {
  return array();
}

function dnd_character_admin_skills() {
  module_load_include('inc', 'dnd_character', 'dnd_character.skills');
  $skills = dnd_character_skill_data();

  $output = array();
  $rows = array();
  $header = array(
    t('Name'),
    t('Description'),
    t('Classes'),
    t('Options'),
  );

  foreach ($skills as $machine_name => $skill) {
    if ($skill['is_subtype']) continue;
    $rows[] = array(
      $skill['name'],
      $skill['teaser'],
      implode(', ', $skill['classes']),
      l('edit', 'admin/config/dnd_character/skills/edit/' . $machine_name, array('query' => array(drupal_get_destination()))),
    );
  }

  $output['table'] = theme('table', array('header' => $header, 'rows' => $rows));

  return $output['table'];
}

function dnd_character_admin_edit_skill() {
  module_load_include('inc', 'dnd_character', 'dnd_character.skills');
  module_load_include('inc', 'dnd_character', 'dnd_character.features.field');

  $form = array();
  $machine_name = check_plain(arg(5));
  $skill = dnd_character_skill_data($machine_name, TRUE);
  $skill += array(
    'machine_name' => '',
    'name' => '',
    'ability' => '',
    'ability_key' => 0,
    'classes' => array(),
    'subtype' => array(),
    'trained' => TRUE,
    'teaser' => '',
    'description' => '',
  );

  $form['original_machine_name'] = array(
    '#type' => 'hidden',
    '#value' => $skill['machine_name'],
  );

  $form['machine_name'] = array(
    '#type' => 'textfield',
    '#title' => t('Machine name'),
    '#description' => t('The machine name of the skill.'),
    '#default_value' => $skill['machine_name'],
  );
  $form['name'] = array(
    '#type' => 'textfield',
    '#title' => t('Name'),
    '#description' => t('The human-readable name of the skill.'),
    '#default_value' => $skill['name'],
  );
  $form['ability_key'] = array(
    '#type' => 'select',
    '#title' => t('Ability'),
    '#description' => t('The ability that this skill depends on (and modifies the skill points).'),
    '#options' => array(
      0 => t('Strength'),
      1 => t('Desterity'),
      2 => t('Constitution'),
      3 => t('Inelligence'),
      4 => t('Wisdom'),
      5 => t('Charisma'),
    ),
    '#default_value' => $skill['ability_key'],
  );

  $default_fields = dnd_character_field_default_fields();
  $classes = ($default_fields['node-dnd_character-field_dnd_character_class_level']['field_config']['settings']['class']);
  $classes = explode("\n", $classes);
  $class_options = array();
  foreach ($classes as $class) {
    if (!empty($class)) {
      list($key, $value) = explode('|', $class);
      $class_options[$key] = $value;
    }
  }
  $form['classes'] = array(
    '#type' => 'select',
    '#title' => t('Classes'),
    '#description' => t('The classes that can take this skill without a penalty (taken as a class skill).'),
    '#options' => $class_options,
    '#default_value' => $skill['ability_key'],
    '#multiple' => TRUE,
  );

  $form['teaser'] = array(
    '#title' => t('Teaser'),
    '#description' => t('A brief version of the skill description, used on character sheets (one-liner)'),
    '#type' => 'textarea',
    '#default_value' => $skill['teaser'],
    '#rows' => 2,
  );

  $form['description'] = array(
    '#title' => t('Teaser'),
    '#description' => t('The full text (HTML) description of the skill.'),
    '#type' => 'textarea',
    '#default_value' => $skill['description'],
    '#rows' => 10,
  );

  $form['trained'] = array(
    '#title' => t('Trained'),
    '#description' => t('Does the character need to be trained to use this skill?'),
    '#type' => 'checkbox',
    '#default_value' => $skill['trained'],
  );

  $form['submit'] = array(
    '#type' => 'submit',
    '#value' => t('Save'),
  );

  return $form;
}

function dnd_character_admin_edit_skill_submit($form, &$form_state) {
  $values = $form_state['values'];

  $abilities = array(
    0 => 'str',
    1 => 'dex',
    2 => 'con',
    3 => 'int',
    4 => 'wis',
    5 => 'chr',
  );

  $record = array(
    'machine_name' => $values['machine_name'],
    'name' => $values['name'],
    'ability' => $abilities[$values['ability_key']],
    'ability_key' => $values['ability_key'],
    'classes' => $values['classes'],
    //'subtype' => $values['subtype'],
    'trained' => $values['trained'],
    'teaser' => $values['teaser'],
    'description' => $values['description'],
  );

  if (!empty($machine_name)) {
    drupal_write_record('dnd_character_skill', $record, array('machine_name'));
  }
  else {
    drupal_write_record('dnd_character_skill', $record);
  }
}
