<?php

/**
 * @file
 * File of theme and template related helper functions for displaying D&D
 * Character nodes in a somewhat decent fashion.
 *
 */

/**
 * Create the themed view of the character's race and name for use in the node
 * template.
 */
function _dnd_character_template_basic_data(&$variables) {
  module_load_include('inc', 'dnd_character', 'dnd_character.api');

  // Create a tabular display for the character's name and race
  $node = $variables['node'];
  $race = field_get_items('node', $node, 'field_dnd_character_race', $node->language);
  $race_data = dnd_character_get_race_data($race[0]['value']);

  $alignment = field_get_items('node', $node, 'field_dnd_character_alignment', $node->language);
  $alignment = dnd_character_get_alignment_data($alignment[0]['value']);

  $header = array(t('Name'), t('Race'), t('Alignment'));
  $rows = array(array($node->title, $race_data['name'], $alignment));
  $variables['name_race'] = theme('table', array('header' => $header, 'rows' => $rows));

  // Add the classes/levels table as a separate template variable
  $class_levels = field_get_items('node', $node, 'field_dnd_character_class_level', $node->language);
  $header = array(t('Class'), t('Level'));
  $rows = array();
  foreach ($class_levels as $class_level) {
    $rows[] = $class_level;
  }
  $variables['content']['class_levels'] = theme('table', array('header' => $header, 'rows' => $rows));

  $hp = field_get_items('node', $node, 'field_dnd_character_hp', $node->language);
  list ($armor_bonus, $shield_bonus, $ability_mod, $size_mod, $misc_mod) = array(
    field_get_items('node', $node, 'field_dnd_character_armor_bonus', $node->language),
    field_get_items('node', $node, 'field_dnd_character_shield_bon', $node->language),
    field_get_items('node', $node, 'field_dnd_character_abilities', $node->language),
    field_get_items('node', $node, 'field_dnd_character_ac_size_mod', $node->language),
    field_get_items('node', $node, 'field_dnd_character_ac_misc_modifier', $node->language),
  );

  $ac = 10
    + $armor_bonus[0]['value']
    + $shield_bonus[0]['value']
    + $ability_mod[1]['mod']
    + $size_mod[0]['value']
    + $misc_mod[0]['value'];

  $header = array(t('Hit Points'), t('Armor Class'), t('Armor Bonus'), t('Shield Bonus'), t('Ability Modifier'), t('Size Modifier'), t('Misc Modifier'));
  $rows = array(
    array(
      $hp[0]['value'],
      $ac,
      $armor_bonus[0]['value'],
      $shield_bonus[0]['value'],
      $ability_mod[1]['mod'],
      $size_mod[0]['value'],
      $misc_mod[0]['value'],
    )
  );
  $variables['content']['hp_ac'] = theme('table', array('header' => $header, 'rows' => $rows));
}

function _dnd_character_template_attributes(&$variables) {
  // Add the abilities table as a separate template variable
  $variables['content']['abilities'] = $variables['content']['field_dnd_character_abilities'];
  $variables['content']['abilities']['#label_display'] = 'hidden';

  // Add the saves table as a separate template variable
  $variables['content']['saves'] = $variables['content']['field_dnd_character_saves'];
  $variables['content']['saves']['#label_display'] = 'hidden';
}

function _dnd_character_template_skills(&$variables) {
  module_load_include('inc', 'dnd_character', 'dnd_character.api');
  $skills = dnd_character_node_skills($variables['node']);

  // Add the skills table as a separate template variable
  $variables['content']['skills'] = $variables['content']['field_dnd_character_skills'];

  $rows = array();
  foreach ($skills as $skill) {
    $skill_array = array(
      $skill['name'],
      $skill['points'],
      $skill['ranks'],
      $skill['teaser'],
    );
    $rows[] = $skill_array;
  }
  $header = array(t('Skill'), t('Modifier'), t('Ranks'), t('Description'));
  $variables['content']['skills'][0]['#markup'] = theme('table', array('header' => $header, 'rows' => $rows));

  $variables['content']['skills']['#label_display'] = 'hidden';
}

function _dnd_character_template_feats(&$variables) {
  // Add the skills table as a separate template variable
  $variables['content']['feats'] = $variables['content']['field_dnd_character_feats'];
  $variables['content']['feats']['#label_display'] = 'hidden';
}

function _dnd_character_template_armor(&$variables) {
  $node = $variables['node'];

  $hp = field_get_items('node', $node, 'field_dnd_character_hp', $node->language);
  list ($armor_bonus, $shield_bonus, $ability_mod, $size_mod, $misc_mod) = array(
    field_get_items('node', $node, 'field_dnd_character_armor_bonus', $node->language),
    field_get_items('node', $node, 'field_dnd_character_armor_bonus', $node->language),
    field_get_items('node', $node, 'field_dnd_character_abilities', $node->language),
    field_get_items('node', $node, 'field_dnd_character_ac_size_mod', $node->language),
    field_get_items('node', $node, 'field_dnd_character_ac_misc_modifier', $node->language),
  );

  $ac = 10
    + $armor_bonus[0]['value']
    + $shield_bonus[0]['value']
    + $ability_mod[1]['mod']
    + $size_mod[0]['value']
    + $misc_mod[0]['value'];

  $header = array(t('Armor Class'), t('Armor Bonus'), t('Shield Bonus'), t('Ability Modifier'), t('Size Modifier'), t('Misc Modifier'));
  $rows = array(
    array(
      $ac,
      $armor_bonus[0]['value'],
      $shield_bonus[0]['value'],
      $ability_mod[1]['mod'],
      $size_mod[0]['value'],
      $misc_mod[0]['value'],
    )
  );
  $variables['content']['ac'] = theme('table', array('header' => $header, 'rows' => $rows));

  list ($arcane_spell_fail, $flat_foot, $check_penalty, $vs_touch) = array(
    field_get_items('node', $node, 'field_dnd_character_arcane_fail', $node->language),
    field_get_items('node', $node, 'field_dnd_character_ac_flat_foot', $node->language),
    field_get_items('node', $node, 'field_dnd_character_ac_check_pen', $node->language),
    field_get_items('node', $node, 'field_dnd_character_ac_vs_touch', $node->language),
  );
  $header = array(t('Arcane Spell Fail'), t('Flat Foot'), t('Armor Check Penalty'), t('Vs. Touch'));
  $rows = array(
    array(
      $arcane_spell_fail[0]['value'],
      $flat_foot[0]['value'],
      $check_penalty[0]['value'],
      $vs_touch[0]['value'],
    )
  );
  $variables['content']['ac_scores'] = theme('table', array('header' => $header, 'rows' => $rows));

  $variables['content']['armor'] = $variables['content']['field_dnd_character_armor'][0]['#markup'];

  $ac_modifiers = field_get_items('node', $node, 'field_dnd_character_ac_modifiers', $node->language);
  $variables['content']['ac_modifiers'] = $ac_modifiers[0]['value'];
}

function _dnd_character_template_equipment(&$variables) {
  $fields = array(
    'worn_equipment' => 'field_dnd_character_worn_equip',
    'containers' => 'field_dnd_character_containers',
    'equipment' => 'field_dnd_character_equipment',
  );
  foreach ($fields as $key => $field) {
    $variables['content'][$key] = (empty($variables['content'][$field])) ? NULL : $variables['content'][$field];
    $variables['content'][$key]['#label_display'] = 'hidden';
  }
}

function _dnd_character_template_biography(&$variables) {
  $node = $variables['node'];
  $header = array(
    t('Gender'),
    t('Age'),
    t('Size'),
    t('Height'),
    t('Weight'),
  );
  $data = array(
    'gender' => field_get_items('node', $node, 'field_dnd_character_gender'),
    'age' => field_get_items('node', $node, 'field_dnd_character_age'),
    'size' => field_get_items('node', $node, 'field_dnd_character_size'),
    'height' => field_get_items('node', $node, 'field_dnd_character_height'),
    'weight' => field_get_items('node', $node, 'field_dnd_character_weight'),
  );
  $rows = array();
  foreach ($data as $key => $value) {
    switch ($key) {
      case 'gender':
      case 'size':
        $rows[0][$key] = ucfirst($data[$key][0]['value']);
        break;
      case 'height':
        $rows[0][$key] = round($data[$key][0]['value'] / 12) . '\'';
        $rows[0][$key] .= ($data[$key][0]['value'] % 12) ? ' ' . $data[$key][0]['value'] % 12 . '"' : '';
        break;
      case 'weight':
        $rows[0][$key] = $data[$key][0]['value'] . ' lb (' . round($data[$key][0]['value'] / 14, 1) . ' st)' ;
        break;
      default:
        $rows[0][$key] = $data[$key][0]['value'];
    }
  }
  $variables['content']['description'] = theme('table', array('header' => $header, 'rows' => $rows));

  $header = array(
    t('Skin'),
    t('Hair'),
    t('Eyes'),
    t('Laterality'),
  );
  $data = array(
    field_get_items('node', $node, 'field_dnd_character_skin'),
    field_get_items('node', $node, 'field_dnd_character_hair'),
    field_get_items('node', $node, 'field_dnd_character_eyes'),
    field_get_items('node', $node, 'field_dnd_character_laterality'),
  );
  $rows = array(array($node->title, $node->title));
  foreach ($data as $key => $value) {
    $rows[0][$key] = $data[$key][0]['value'];
  }
  $variables['content']['description'] .= theme('table', array('header' => $header, 'rows' => $rows));

  $fields = array(
    'background' => 'body',
    'history' => 'field_dnd_character_history',
    'goals' => 'field_dnd_character_goals',
    'personality' => 'field_dnd_character_personality',
    'appearance' => 'field_dnd_character_appearance',
    'notes' => 'field_dnd_character_notes',
  );

  foreach ($fields as $key => $field) {
    $variables['content'][$key] = (empty($variables['content'][$field])) ? NULL : $variables['content'][$field];
    $variables['content'][$key]['#label_display'] = 'hidden';
  }
}
