<?php

/**
 * @file
 * Default theme implementation to display a node.
 *
 * Available variables:
 * - $title: the (sanitized) title of the node.
 * - $content: An array of node items. Use render($content) to print them all,
 *   or print a subset such as render($content['field_example']). Use
 *   hide($content['field_example']) to temporarily suppress the printing of a
 *   given element.
 * - $user_picture: The node author's picture from user-picture.tpl.php.
 * - $date: Formatted creation date. Preprocess functions can reformat it by
 *   calling format_date() with the desired parameters on the $created variable.
 * - $name: Themed username of node author output from theme_username().
 * - $node_url: Direct URL of the current node.
 * - $display_submitted: Whether submission information should be displayed.
 * - $submitted: Submission information created from $name and $date during
 *   template_preprocess_node().
 * - $classes: String of classes that can be used to style contextually through
 *   CSS. It can be manipulated through the variable $classes_array from
 *   preprocess functions. The default values can be one or more of the
 *   following:
 *   - node: The current template type; for example, "theming hook".
 *   - node-[type]: The current node type. For example, if the node is a
 *     "Blog entry" it would result in "node-blog". Note that the machine
 *     name will often be in a short form of the human readable label.
 *   - node-teaser: Nodes in teaser form.
 *   - node-preview: Nodes in preview mode.
 *   The following are controlled through the node publishing options.
 *   - node-promoted: Nodes promoted to the front page.
 *   - node-sticky: Nodes ordered above other non-sticky nodes in teaser
 *     listings.
 *   - node-unpublished: Unpublished nodes visible only to administrators.
 * - $title_prefix (array): An array containing additional output populated by
 *   modules, intended to be displayed in front of the main title tag that
 *   appears in the template.
 * - $title_suffix (array): An array containing additional output populated by
 *   modules, intended to be displayed after the main title tag that appears in
 *   the template.
 *
 * Other variables:
 * - $node: Full node object. Contains data that may not be safe.
 * - $type: Node type; for example, story, page, blog, etc.
 * - $comment_count: Number of comments attached to the node.
 * - $uid: User ID of the node author.
 * - $created: Time the node was published formatted in Unix timestamp.
 * - $classes_array: Array of html class attribute values. It is flattened
 *   into a string within the variable $classes.
 * - $zebra: Outputs either "even" or "odd". Useful for zebra striping in
 *   teaser listings.
 * - $id: Position of the node. Increments each time it's output.
 *
 * Node status variables:
 * - $view_mode: View mode; for example, "full", "teaser".
 * - $teaser: Flag for the teaser state (shortcut for $view_mode == 'teaser').
 * - $page: Flag for the full page state.
 * - $promote: Flag for front page promotion state.
 * - $sticky: Flags for sticky post setting.
 * - $status: Flag for published status.
 * - $comment: State of comment settings for the node.
 * - $readmore: Flags true if the teaser content of the node cannot hold the
 *   main body content.
 * - $is_front: Flags true when presented in the front page.
 * - $logged_in: Flags true when the current user is a logged-in member.
 * - $is_admin: Flags true when the current user is an administrator.
 *
 * Field variables: for each field instance attached to the node a corresponding
 * variable is defined; for example, $node->body becomes $body. When needing to
 * access a field's raw values, developers/themers are strongly encouraged to
 * use these variables. Otherwise they will have to explicitly specify the
 * desired field language; for example, $node->body['en'], thus overriding any
 * language negotiation rule that was previously applied.
 *
 * @see template_preprocess()
 * @see template_preprocess_node()
 * @see template_process()
 *
 * @ingroup themeable
 */
?>
<div id="node-<?php print $node->nid; ?>" class="<?php print $classes; ?> clearfix"<?php print $attributes; ?>>

  <?php print $user_picture; ?>

  <?php print render($title_prefix); ?>
  <?php if (!$page): ?>
    <h2<?php print $title_attributes; ?>><a href="<?php print $node_url; ?>"><?php print $title; ?></a></h2>
  <?php endif; ?>
  <?php print render($title_suffix); ?>

  <?php if ($display_submitted): ?>
    <div class="submitted">
      <?php // print $submitted; ?>
    </div>
  <?php endif; ?>

  <?php // Content tabs to display main components of the D&D Character content ?>
  <div class="content"<?php print $content_attributes; ?>>
    <?php if ($page): ?>
      <div class="tabs">
        <ul class="dnd-character-tabs tabs secondary">
          <li class="active"><a href ="#attributes" class="dnd-character-tab active"><?php print t('Attributes'); ?></a></li>
          <li><a href ="#armor" class="dnd-character-tab"><?php print t('Protection'); ?></a></li>
          <li><a href ="#skills" class="dnd-character-tab"><?php print t('Skills'); ?></a></li>
          <li><a href ="#feats" class="dnd-character-tab"><?php print t('Feats'); ?></a></li>
          <li><a href ="#equipment" class="dnd-character-tab"><?php print t('Equipment'); ?></a></li>
          <li><a href ="#biography" class="dnd-character-tab"><?php print t('Biography'); ?></a></li>
        </ul>
      </div>
    <?php endif; ?>

    <?php // The block of content that will always appear to display the basic information about the character ?>
    <div class="dnd-character-basics">

      <div class="dnd-character-col-1">
        <?php print $name_race; ?>
      </div>

      <div class="dnd-character-col-1">
        <?php print render($content['class_levels']); ?>
      </div>

      <div class="dnd-character-col-2 clearfix" style="clear:both">
        <?php print render($content['hp_ac']); ?>
      </div>

    </div>

    <?php if ($page): ?>
    <div class="dnd-character-content" id="dnd-character-attributes">
      <div class="dnd-character-content-page dnd-character-content-page-active" id="dnd-character-page-attributes">
        <h3>Ability Scores</h3>
        <?php print render($content['abilities']); ?>
        <h3>Saving Throws</h3>
        <?php print render($content['saves']); ?>
      </div>
      <div class="dnd-character-content-page" id="dnd-character-page-armor">
        <h3>Armor Class</h3>
        <?php print render($content['ac']); ?>
        <?php print render($content['ac_scores']); ?>
        <h3>Armor</h3>
        <?php print render($content['armor']); ?>
        <h3>AC Modifiers</h3>
        <?php print render($content['ac_modifiers']); ?>
      </div>
      <div class="dnd-character-content-page" id="dnd-character-page-skills">
        <h3>Skills</h3>
        <?php print render($content['skills']); ?>
      </div>
      <div class="dnd-character-content-page" id="dnd-character-page-feats">
        <h3>Feats</h3>
        <?php print render($content['feats']); ?>
      </div>
      <div class="dnd-character-content-page" id="dnd-character-page-equipment">
        <h3>Worn Equipment</h3>
        <?php print render($content['worn_equipment']); ?>

        <div class="dnd-character-col-1 clearfix">
          <h3><?php print render($content['containers'][0]); ?></h3>
          <?php print check_markup(render($content['equipment'][0])); ?>
        </div>

        <div class="dnd-character-col-1 clearfix">
          <h3><?php print render($content['containers'][1]); ?></h3>
          <?php print check_markup(render($content['equipment'][1])); ?>
        </div>

        <br clear="all" />
      </div>
      <div class="dnd-character-content-page" id="dnd-character-page-biography">
        <h3>Description</h3>
        <?php print render($content['description']); ?>
        <h3>Background</h3>
        <?php print render($content['background']); ?>
        <h3>History</h3>
        <?php print render($content['history']); ?>
        <h3>Goals</h3>
        <?php print render($content['goals']); ?>
        <h3>Personality/Behavior</h3>
        <?php print render($content['personality']); ?>
        <h3>Appearance</h3>
        <?php print render($content['appearance']); ?>
        <h3>Notes</h3>
        <?php print render($content['notes']); ?>
      </div>

      <?php
        // We hide the comments and links now so that we can render them later.
        hide($content['comments']);
        hide($content['links']);
        //print render($content);
      ?>
    </div>
  </div>

  <div>
    <p><?php print l('PDF Character Sheet', 'node/' . $node->nid . '/sheet'); ?></p>
  </div>

  <?php endif; ?>

  <?php print render($content['links']); ?>

  <?php // print render($content['comments']); ?>

</div>
